@@ -18,7 +18,8 @@ class Components:
                    placeholder="Select Sorting Method",
                    value='Top 20 Net Profit',
                    options=[{'label': 'Top 20 Net Profit', 'value': 'Top 20 Net Profit'},
-                            {'label': 'Top 20 Net Profit to MDD', 'value': 'Top 20 Net Profit to MDD'}, ],
+                            {'label': 'Top 20 Return/BaH Ratio', 'value': 'Top 20 Return to BaH Ratio'},
+                            {'label': 'Top 20 Net Profit/MDD Ratio', 'value': 'Top 20 Net Profit to MDD'}, ],
                    style={'border-radius': '5px',   'font-size': '12px', }),
         style={'padding-left': '12.5px', 'width': '240px'})
 
@@ -28,8 +29,8 @@ class Components:
                                                    placeholder="Select Filter",
                                                    options=[
                                                        {'label': 'Exclude Stock', 'value': 'exclude'},
-                                                       {'label': 'Return to BaH Ratio >', 'value': 'return_to_bah>'},
-                                                       {'label': 'Return to BaH Ratio <', 'value': 'return_to_bah<'},
+                                                       {'label': 'Return/BaH Ratio >', 'value': 'return_to_bah>'},
+                                                       {'label': 'Return/BaH Ratio <', 'value': 'return_to_bah<'},
                                                        {'label': 'Sharp Ratio >', 'value': 'annualized_sr>'},
                                                        {'label': 'Sharp Ratio <', 'value': 'annualized_sr<'},
                                                        {'label': 'MDD Percentage >', 'value': 'mdd_pct>'},
@@ -122,22 +123,17 @@ class Components:
 
     def update_stat_div(self, period, pct_mean, rise_mean, fall_mean):
         div = html.Div([
-            # html.Div(style={'height': '15px', }),
-
-             # html.Div('Average', style={'text-align': 'left'}),
-             #
-             # html.Div(style={'height': '5px', }),
 
             dbc.Row([
                  dbc.Col(width=2),
-                 dbc.Col(str(period[0]) + ' Days',width=2),
+                 dbc.Col(str(period[0]) + ' Days', width=2),
                  dbc.Col(str(period[1]) + ' Days', width=2),
                  dbc.Col(str(period[2]) + ' Days', width=2),
                  dbc.Col(str(period[3]) + ' Days', width=2),
                  dbc.Col(str(period[4]) + ' Days', width=2),
              ]),
 
-            html.Div(style={'height': '5px', }),
+            # html.Div(style={'height': '5px', }),
 
             dbc.Row([
                  dbc.Col('pct_change', width=2),
@@ -148,7 +144,7 @@ class Components:
                  dbc.Col(f'{pct_mean[4]}%', width=2),
              ]),
 
-            html.Div(style={'height': '5px', }),
+            # html.Div(style={'height': '5px', }),
 
             dbc.Row([
                  dbc.Col('max_rise', width=2),
@@ -159,7 +155,7 @@ class Components:
                  dbc.Col(f'{rise_mean[4]}%', width=2),
              ]),
 
-            html.Div(style={'height': '5px', }),
+            # html.Div(style={'height': '5px', }),
 
             dbc.Row([
                  dbc.Col('max_fall', width=2),
@@ -170,7 +166,7 @@ class Components:
                  dbc.Col(f'{fall_mean[4]}%', width=2),
              ]),
 
-            html.Div(style={'height': '15px', }),
+            # html.Div(style={'height': '15px', }),
         ])
 
         return div
@@ -182,7 +178,7 @@ class Components:
         for i, key in enumerate(para_dict):
             options = para_dict[key]
 
-            radioitems_div.append(html.Div(key,style={'color': 'Yellow','font-size': '16px'}))
+            radioitems_div.append(html.Div(key,style={'color': 'Yellow','font-size': '14px'}))
 
             radioitems_div.append(dcc.RadioItems(
                 id={'type': 'para_radioitems', 'index': i},
@@ -210,10 +206,10 @@ class Components:
         keys = ['num_of_trade',
                 'net_profit',
                 'net_profit_to_mdd',
-                'total_commission',
                 'return_to_bah',
                 'win_rate',
                 'cov',
+                'total_commission',
                 'return_on_capital',
                 'annualized_return',
                 'annualized_std',
@@ -256,10 +252,10 @@ class Components:
         per_col_1_1.append(html.Div('Number of Trade'))
         per_col_1_1.append(html.Div('Net Profit'))
         per_col_1_1.append(html.Div('Net Profit/MDD Ratio'))
-        per_col_1_1.append(html.Div('Total Commission'))
         per_col_1_1.append(html.Div('Return/BaH Ratio'))
         per_col_1_1.append(html.Div('Win Rate'))
         per_col_1_1.append(html.Div('COV'))
+        per_col_1_1.append(html.Div('Total Commission'))
 
         per_col_2_1.append(html.Div('Return on Capital'))
         per_col_2_1.append(html.Div('Ann. Return'))
@@ -338,15 +334,11 @@ class Components:
 
 
     def selection_title(self, para_dict, values):
-        title = [html.Div('Selected',style={'color':'Cyan','font-size': '15px'})]
+        title = []
         for i, key in enumerate(para_dict):
-            title_div = []
-            title_div.append(html.Div(key, style={'margin-right': '5px', 'display': 'inline'}))
-            title_div.append(html.Div(':', style={'margin-right': '5px', 'display': 'inline'}))
-            title_div.append(html.Div(str(values[i]) + ' ', style={'margin-right': '10px', 'display': 'inline'}))
-            title.append(html.Span(title_div))
-        title.append(html.Div(style={'height': '15px', }),)
-        title.append(html.Div('Performance',style={'color':'Cyan','font-size': '15px'}))
+            title.append(dbc.Row(
+                [dbc.Col(key, width=6),
+                 dbc.Col(f'{values[i]}', style={'text-align': 'center'}, width=6)]))
 
         return title
 
@@ -390,6 +382,8 @@ class Components:
             df_sorted = result_df.sort_values(by='net_profit', ascending=False).head(20).copy()
         elif sort_method == 'Top 20 Net Profit to MDD':
             df_sorted = result_df.sort_values(by='net_profit_to_mdd', ascending=False).head(20).copy()
+        elif sort_method == 'Top 20 Return to BaH Ratio':
+            df_sorted = result_df.sort_values(by='return_to_bah', ascending=False).head(20).copy()
         else:
             df_sorted = result_df.copy()
 
@@ -702,9 +696,9 @@ class Components:
 
         df_his = df_his[['date'] + [col_pct, col_rise, col_fall]]
 
-        margin = dict(l=5, r=5, t=5, b=5)
-        h = 85
-        w = 140
+        margin = dict(l=5, r=5, t=5, b=15)
+        h = 70
+        w = 120
         f = {"color": "white", 'size': 8}
 
         fig_pct = go.Figure()
