@@ -1,5 +1,4 @@
 from dash import Dash, dcc, html, Input, Output, State, ALL
-
 from .components import *
 
 class Plot:
@@ -55,7 +54,7 @@ class Plot:
                         html.Div(style={'height': '10px', }),
                         html.Div(id='checklist-container',children=checkbox_div),
                         html.Div('--------------------------------------',style={'margin-left': '15px'}),
-                        html.Div('Filters for:', style={'margin-left': '12px'}),
+                        html.Div('Filters for:', style={'font-size': '14px', 'margin-left': '12px'}),
                         html.Div(style={'height': '10px', }),
                         html.Div(id='filter', children=filter_div,style={'padding': '0px 20px',
                                                                          'padding-right': '30px',
